from distutils.core import setup

setup(
        name = "chenlayz",
        version = "1.0.0",
        py_modules = ['nester'],
        author = 'chenanze',
        author_email = 'chenanze@live.com',
        url = 'http://www.chenanze.com',
        description = 'A simple printer of neted lists',
    )
